Class: Google::Cloud::DatabaseCenter::V1beta::AggregateFleetResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

The response message to aggregate a fleet by some group by fields.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



557
558
559
560
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 557

class AggregateFleetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_groups_total_count::Integer

Returns Count of all resource groups in the fleet. This includes counts from all pages.

Returns:

  • (::Integer)

    Count of all resource groups in the fleet. This includes counts from all pages.



557
558
559
560
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 557

class AggregateFleetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_total_count::Integer

Returns Count of all resources in the fleet. This includes counts from all pages.

Returns:

  • (::Integer)

    Count of all resources in the fleet. This includes counts from all pages.



557
558
559
560
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 557

class AggregateFleetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rows::Array<::Google::Cloud::DatabaseCenter::V1beta::AggregateFleetRow>

Returns Represents a row grouped by the fields in the input.

Returns:



557
558
559
560
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 557

class AggregateFleetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. List of unreachable regions from where data could not be retrieved.

Returns:

  • (::Array<::String>)

    Unordered list. List of unreachable regions from where data could not be retrieved.



557
558
559
560
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 557

class AggregateFleetResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end