Class: Google::Cloud::DatabaseCenter::V1beta::AggregateFleetRow
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::AggregateFleetRow
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
Individual row grouped by a particular dimension.
Instance Attribute Summary collapse
-
#delta_details ⇒ ::Google::Cloud::DatabaseCenter::V1beta::DeltaDetails
Optional.
-
#dimension ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Dimension>
Group by dimension.
-
#resource_groups_count ⇒ ::Integer
Number of resource groups that have a particular dimension.
-
#resources_count ⇒ ::Integer
Number of resources that have a particular dimension.
Instance Attribute Details
#delta_details ⇒ ::Google::Cloud::DatabaseCenter::V1beta::DeltaDetails
Returns Optional. Delta counts and details of resources which were added to/deleted from fleet.
576 577 578 579 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 576 class AggregateFleetRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dimension ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Dimension>
Returns Group by dimension.
576 577 578 579 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 576 class AggregateFleetRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_groups_count ⇒ ::Integer
Returns Number of resource groups that have a particular dimension.
576 577 578 579 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 576 class AggregateFleetRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resources_count ⇒ ::Integer
Returns Number of resources that have a particular dimension.
576 577 578 579 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 576 class AggregateFleetRow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |