Class: Google::Cloud::DatabaseCenter::V1beta::AggregateIssueStatsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

AggregateIssueStatsRequest represents the input to the AggregateIssueStats method.

Instance Attribute Summary collapse

Instance Attribute Details

#baseline_date::Google::Type::Date

Returns Optional. The baseline date w.r.t. which the delta counts are calculated. If not set, delta counts are not included in the response and the response indicates the current state of the fleet.

Returns:

  • (::Google::Type::Date)

    Optional. The baseline date w.r.t. which the delta counts are calculated. If not set, delta counts are not included in the response and the response indicates the current state of the fleet.



355
356
357
358
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 355

class AggregateIssueStatsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#filter::String

Returns Optional. The expression to filter resources.

Supported fields are: full_resource_name, resource_type, container, product.type, product.engine, product.version, location, labels, issues, fields of availability_info, data_protection_info,'resource_name', etc.

The expression is a list of zero or more restrictions combined via logical operators AND and OR. When AND and OR are both used in the expression, parentheses must be appropriately used to group the combinations.

Example: location="us-east1" Example: container="projects/123" OR container="projects/456" Example: (container="projects/123" OR container="projects/456") AND location="us-east1".

Returns:

  • (::String)

    Optional. The expression to filter resources.

    Supported fields are: full_resource_name, resource_type, container, product.type, product.engine, product.version, location, labels, issues, fields of availability_info, data_protection_info,'resource_name', etc.

    The expression is a list of zero or more restrictions combined via logical operators AND and OR. When AND and OR are both used in the expression, parentheses must be appropriately used to group the combinations.

    Example: location="us-east1" Example: container="projects/123" OR container="projects/456" Example: (container="projects/123" OR container="projects/456") AND location="us-east1"



355
356
357
358
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 355

class AggregateIssueStatsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent can be a project, a folder, or an organization. The search is limited to the resources within the scope.

The allowed values are:

  • projects/{PROJECT_ID} (e.g., "projects/foo-bar")
  • projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
  • folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
  • organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456").

Returns:

  • (::String)

    Required. Parent can be a project, a folder, or an organization. The search is limited to the resources within the scope.

    The allowed values are:

    • projects/{PROJECT_ID} (e.g., "projects/foo-bar")
    • projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
    • folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
    • organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456")


355
356
357
358
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 355

class AggregateIssueStatsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signal_type_groups::Array<::Google::Cloud::DatabaseCenter::V1beta::SignalTypeGroup>

Returns Optional. Lists of signal types that are issues.

Returns:



355
356
357
358
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 355

class AggregateIssueStatsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end