Class: Google::Cloud::DatabaseCenter::V1beta::AggregateQueryStatsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

The response message containing relevant query stats for database resources.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



434
435
436
437
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 434

class AggregateQueryStatsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query_stats::Array<::Google::Cloud::DatabaseCenter::V1beta::QueryStatsInfo>

Returns List of query stats where each group contains stats for resources having a particular combination of relevant query stats.

Returns:



434
435
436
437
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 434

class AggregateQueryStatsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. List of unreachable regions from where data could not be retrieved.

Returns:

  • (::Array<::String>)

    Unordered list. List of unreachable regions from where data could not be retrieved.



434
435
436
437
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 434

class AggregateQueryStatsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end