Class: Google::Cloud::DatabaseCenter::V1beta::DeltaDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

Captures the details of items that have increased or decreased in some bucket when compared to some point in history. It is currently used to capture the delta of resources that have been added or removed in the fleet as well as to capture the resources that have a change in Issue/Signal status.

Instance Attribute Summary collapse

Instance Attribute Details

#decreased_resources::Array<::Google::Cloud::DatabaseCenter::V1beta::ResourceDetails>

Returns Details of resources that have decreased.

Returns:



852
853
854
855
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 852

class DeltaDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#increased_resources::Array<::Google::Cloud::DatabaseCenter::V1beta::ResourceDetails>

Returns Details of resources that have increased.

Returns:



852
853
854
855
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 852

class DeltaDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end