Class: Google::Cloud::DatabaseCenter::V1beta::Dimension

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

Dimension used to aggregate the fleet.

Instance Attribute Summary collapse

Instance Attribute Details

#container::String

Returns Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.

Note: The following fields are mutually exclusive: container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.

    Note: The following fields are mutually exclusive: container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#edition::Google::Cloud::DatabaseCenter::V1beta::Edition

Returns The edition of the resource.

Note: The following fields are mutually exclusive: edition, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::Edition)

    The edition of the resource.

    Note: The following fields are mutually exclusive: edition, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#has_deny_maintenance_schedules::Boolean

Returns Whether the resource has deny maintenance schedules.

Note: The following fields are mutually exclusive: has_deny_maintenance_schedules, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Whether the resource has deny maintenance schedules.

    Note: The following fields are mutually exclusive: has_deny_maintenance_schedules, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#has_maintenance_schedule::Boolean

Returns Whether the resource has a maintenance schedule.

Note: The following fields are mutually exclusive: has_maintenance_schedule, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Whether the resource has a maintenance schedule.

    Note: The following fields are mutually exclusive: has_maintenance_schedule, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label_key::String

Returns Label key of the resource.

Note: The following fields are mutually exclusive: label_key, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Label key of the resource.

    Note: The following fields are mutually exclusive: label_key, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label_source::String

Returns Label source of the resource.

Note: The following fields are mutually exclusive: label_source, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Label source of the resource.

    Note: The following fields are mutually exclusive: label_source, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label_value::String

Returns Label value of the resource.

Note: The following fields are mutually exclusive: label_value, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Label value of the resource.

    Note: The following fields are mutually exclusive: label_value, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns The location of the resources. It supports returning only regional locations in Google Cloud.

Note: The following fields are mutually exclusive: location, container, product_type, product_engine, product_version, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The location of the resources. It supports returning only regional locations in Google Cloud.

    Note: The following fields are mutually exclusive: location, container, product_type, product_engine, product_version, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#management_type::Google::Cloud::DatabaseCenter::V1beta::ManagementType

Returns The management type of the resource.

Note: The following fields are mutually exclusive: management_type, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::ManagementType)

    The management type of the resource.

    Note: The following fields are mutually exclusive: management_type, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product_engine::Google::Cloud::DatabaseCenter::V1beta::Engine

Returns Engine refers to underlying database binary running in an instance.

Note: The following fields are mutually exclusive: product_engine, container, product_type, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::Engine)

    Engine refers to underlying database binary running in an instance.

    Note: The following fields are mutually exclusive: product_engine, container, product_type, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product_type::Google::Cloud::DatabaseCenter::V1beta::ProductType

Returns Type to identify a product

Note: The following fields are mutually exclusive: product_type, container, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::ProductType)

    Type to identify a product

    Note: The following fields are mutually exclusive: product_type, container, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product_version::String

Returns Version of the underlying database engine

Note: The following fields are mutually exclusive: product_version, container, product_type, product_engine, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Version of the underlying database engine

    Note: The following fields are mutually exclusive: product_version, container, product_type, product_engine, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_category::Google::Cloud::DatabaseCenter::V1beta::ResourceCategory

Returns The category of the resource.

Note: The following fields are mutually exclusive: resource_category, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::ResourceCategory)

    The category of the resource.

    Note: The following fields are mutually exclusive: resource_category, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_type::String

Returns The type of resource defined according to the pattern: {Service Name}/{Type}. Ex: sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.googleapis.com/Instance spanner.googleapis.com/Instance

Note: The following fields are mutually exclusive: resource_type, container, product_type, product_engine, product_version, location, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    The type of resource defined according to the pattern: {Service Name}/{Type}. Ex: sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.googleapis.com/Instance spanner.googleapis.com/Instance

    Note: The following fields are mutually exclusive: resource_type, container, product_type, product_engine, product_version, location, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sub_resource_type::Google::Cloud::DatabaseCenter::V1beta::SubResourceType

Returns Subtype of the resource specified at creation time.

Note: The following fields are mutually exclusive: sub_resource_type, container, product_type, product_engine, product_version, location, resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::SubResourceType)

    Subtype of the resource specified at creation time.

    Note: The following fields are mutually exclusive: sub_resource_type, container, product_type, product_engine, product_version, location, resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag_inherited::Boolean

Returns Tag inheritance value of the resource.

Note: The following fields are mutually exclusive: tag_inherited, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Tag inheritance value of the resource.

    Note: The following fields are mutually exclusive: tag_inherited, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_source, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag_key::String

Returns Tag key of the resource.

Note: The following fields are mutually exclusive: tag_key, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Tag key of the resource.

    Note: The following fields are mutually exclusive: tag_key, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_value, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag_source::String

Returns Tag source of the resource.

Note: The following fields are mutually exclusive: tag_source, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Tag source of the resource.

    Note: The following fields are mutually exclusive: tag_source, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_value, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tag_value::String

Returns Tag value of the resource.

Note: The following fields are mutually exclusive: tag_value, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Tag value of the resource.

    Note: The following fields are mutually exclusive: tag_value, container, product_type, product_engine, product_version, location, resource_type, sub_resource_type, resource_category, management_type, edition, tag_key, tag_source, tag_inherited, label_key, label_value, label_source, has_maintenance_schedule, has_deny_maintenance_schedules. If a field in that set is populated, all other fields in the set will automatically be cleared.



684
685
686
687
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 684

class Dimension
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end