Class: Google::Cloud::DatabaseCenter::V1beta::InefficientQueryInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/signals.rb

Overview

Metadata about inefficient query signal info for a database resource.

Instance Attribute Summary collapse

Instance Attribute Details

#database::String

Returns Name of the database where index is required. For example, "db1", which is the name of the database present in the instance.

Returns:

  • (::String)

    Name of the database where index is required. For example, "db1", which is the name of the database present in the instance.



335
336
337
338
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 335

class InefficientQueryInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#impacted_queries_count::Integer

Returns Count of queries to be impacted if index is applied.

Returns:

  • (::Integer)

    Count of queries to be impacted if index is applied



335
336
337
338
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 335

class InefficientQueryInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sql_index_statement::String

Returns SQL statement of the index. Based on the ddl type, this will be either CREATE INDEX or DROP INDEX.

Returns:

  • (::String)

    SQL statement of the index. Based on the ddl type, this will be either CREATE INDEX or DROP INDEX.



335
336
337
338
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 335

class InefficientQueryInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#storage_cost_bytes::Integer

Returns Cost of additional disk usage in bytes.

Returns:

  • (::Integer)

    Cost of additional disk usage in bytes



335
336
337
338
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 335

class InefficientQueryInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#table::String

Returns Name of the table where index is required.

Returns:

  • (::String)

    Name of the table where index is required



335
336
337
338
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 335

class InefficientQueryInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end