Class: Google::Cloud::DatabaseCenter::V1beta::IssueGroupStats

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

IssueGroupStats refers to stats for a particulare combination of relevant health issues of database resources.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Database resource level health card name. This will corresponds to one of the requested input group names.

Returns:

  • (::String)

    Database resource level health card name. This will corresponds to one of the requested input group names.



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#healthy_resource_groups_count::Integer

Returns The number of resource groups from the total groups as defined above that are healthy with respect to all of the specified issues.

Returns:

  • (::Integer)

    The number of resource groups from the total groups as defined above that are healthy with respect to all of the specified issues.



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#healthy_resources_count::Integer

Returns The number of resources from the total defined above in field total_resources_count that are healthy with respect to all of the specified issues.

Returns:

  • (::Integer)

    The number of resources from the total defined above in field total_resources_count that are healthy with respect to all of the specified issues.



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issue_stats::Array<::Google::Cloud::DatabaseCenter::V1beta::IssueStats>

Returns List of issues stats containing count of resources having particular issue category.

Returns:



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_groups_count::Integer

Returns Total count of the groups of resources returned by the filter that also have one or more resources for which any of the specified issues are applicable.

Returns:

  • (::Integer)

    Total count of the groups of resources returned by the filter that also have one or more resources for which any of the specified issues are applicable.



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resources_count::Integer

Returns Total count of resources returned by the filter for which any of the specified issues are applicable.

Returns:

  • (::Integer)

    Total count of resources returned by the filter for which any of the specified issues are applicable.



409
410
411
412
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 409

class IssueGroupStats
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end