Class: Google::Cloud::DatabaseCenter::V1beta::MaintenanceInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb

Overview

MaintenanceInfo to capture the maintenance details of database resource.

Instance Attribute Summary collapse

Instance Attribute Details

#current_version_release_date::Google::Type::Date (readonly)

Returns Output only. The date when the maintenance version was released.

Returns:



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deny_maintenance_schedules::Array<::Google::Cloud::DatabaseCenter::V1beta::ResourceMaintenanceDenySchedule>

Returns Optional. List of Deny maintenance period for the database resource.

Returns:



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#maintenance_schedule::Google::Cloud::DatabaseCenter::V1beta::ResourceMaintenanceSchedule

Returns Optional. Maintenance window for the database resource.

Returns:



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#maintenance_version::String (readonly)

Returns Output only. Current Maintenance version of the database resource. Example: "MYSQL_8_0_41.R20250531.01_15".

Returns:

  • (::String)

    Output only. Current Maintenance version of the database resource. Example: "MYSQL_8_0_41.R20250531.01_15"



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#possible_failure_reasons::Array<::Google::Cloud::DatabaseCenter::V1beta::PossibleFailureReason> (readonly)

Returns Output only. List of possible reasons why the maintenance is not completed. This is an optional field and is only populated if there are any reasons for failures recorded for the maintenance by DB Center. FAILURE maintenance status may not always have a failure reason.

Returns:

  • (::Array<::Google::Cloud::DatabaseCenter::V1beta::PossibleFailureReason>)

    Output only. List of possible reasons why the maintenance is not completed. This is an optional field and is only populated if there are any reasons for failures recorded for the maintenance by DB Center. FAILURE maintenance status may not always have a failure reason.



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#previous_maintenance_version::String (readonly)

Returns Output only. Previous maintenance version of the database resource. Example: "MYSQL_8_0_41.R20250531.01_15". This is available once a minor version maintenance is complete on a database resource.

Returns:

  • (::String)

    Output only. Previous maintenance version of the database resource. Example: "MYSQL_8_0_41.R20250531.01_15". This is available once a minor version maintenance is complete on a database resource.



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#state::Google::Cloud::DatabaseCenter::V1beta::MaintenanceState (readonly)

Returns Output only. Resource maintenance state. This is to capture the current state of the maintenance.

Returns:



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#upcoming_maintenance::Google::Cloud::DatabaseCenter::V1beta::UpcomingMaintenance (readonly)

Returns Output only. Upcoming maintenance window for the database resource. This is only populated for an engine, if upcoming maintenance is scheduled for the resource. This schedule is generated per engine and engine version, and there is only one upcoming maintenance window at any given time. In case of upcoming maintenance, the maintenance_state will be set to SCHEDULED first, and then IN_PROGRESS when the maintenance window starts.

Returns:

  • (::Google::Cloud::DatabaseCenter::V1beta::UpcomingMaintenance)

    Output only. Upcoming maintenance window for the database resource. This is only populated for an engine, if upcoming maintenance is scheduled for the resource. This schedule is generated per engine and engine version, and there is only one upcoming maintenance window at any given time. In case of upcoming maintenance, the maintenance_state will be set to SCHEDULED first, and then IN_PROGRESS when the maintenance window starts.



117
118
119
120
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 117

class MaintenanceInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end