Class: Google::Cloud::DatabaseCenter::V1beta::MetricData
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::MetricData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb
Overview
MetricData represents the metric data for a database resource.
Instance Attribute Summary collapse
-
#observation_time ⇒ ::Google::Protobuf::Timestamp
The time the metric was observed in the metric source service.
-
#value ⇒ ::Google::Cloud::DatabaseCenter::V1beta::TypedValue
The value associated with the metric.
Instance Attribute Details
#observation_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the metric was observed in the metric source service.
69 70 71 72 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 69 class MetricData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#value ⇒ ::Google::Cloud::DatabaseCenter::V1beta::TypedValue
Returns The value associated with the metric.
69 70 71 72 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 69 class MetricData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |