Class: Google::Cloud::DatabaseCenter::V1beta::Metrics
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::Metrics
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb
Overview
Metrics represents the metrics for a database resource.
Instance Attribute Summary collapse
-
#current_memory_used_bytes ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Current memory used by the resource in bytes.
-
#current_storage_used_bytes ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Current storage used by the resource in bytes.
-
#node_count ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Number of nodes in instance for spanner or bigtable.
-
#p95_cpu_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
P95 CPU utilization observed for the resource.
-
#p99_cpu_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
P99 CPU utilization observed for the resource.
-
#peak_memory_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Peak memory utilization observed for the resource.
-
#peak_number_connections ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Peak number of connections observed for the resource.
-
#peak_storage_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Peak storage utilization observed for the resource.
-
#processing_unit_count ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Number of processing units in spanner.
Instance Attribute Details
#current_memory_used_bytes ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Current memory used by the resource in bytes.
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#current_storage_used_bytes ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Current storage used by the resource in bytes.
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#node_count ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Number of nodes in instance for spanner or bigtable.
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#p95_cpu_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns P95 CPU utilization observed for the resource. The value is a fraction between 0.0 and 1.0 (may momentarily exceed 1.0 in some cases).
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#p99_cpu_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns P99 CPU utilization observed for the resource. The value is a fraction between 0.0 and 1.0 (may momentarily exceed 1.0 in some cases).
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#peak_memory_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Peak memory utilization observed for the resource. The value is a fraction between 0.0 and 1.0 (may momentarily exceed 1.0 in some cases).
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#peak_number_connections ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Peak number of connections observed for the resource. The value is a positive integer.
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#peak_storage_utilization ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Peak storage utilization observed for the resource. The value is a fraction between 0.0 and 1.0 (may momentarily exceed 1.0 in some cases).
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#processing_unit_count ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MetricData
Returns Number of processing units in spanner.
57 58 59 60 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/metric_data.rb', line 57 class Metrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |