Class: Google::Cloud::DatabaseCenter::V1beta::QueryIssuesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

QueryIssuesRequest is the request to get a list of issues.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Supported fields are: 'product', location, issue_severity, 'tags', 'labels',.

Returns:

  • (::String)

    Optional. Supported fields are: 'product', location, issue_severity, 'tags', 'labels',



743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Following fields are sortable: SignalType Product Location IssueSeverity

The default order is ascending. Add "DESC" after the field name to indicate descending order. Add "ASC" after the field name to indicate ascending order. It only supports a single field at a time.

Returns:

  • (::String)

    Optional. Following fields are sortable: SignalType Product Location IssueSeverity

    The default order is ascending. Add "DESC" after the field name to indicate descending order. Add "ASC" after the field name to indicate ascending order. It only supports a single field at a time.



743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. If unspecified, at most 50 issues will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. If unspecified, at most 50 issues will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous QueryIssues call. Provide this to retrieve the subsequent page. All parameters except page size should match the parameters used in the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous QueryIssues call. Provide this to retrieve the subsequent page. All parameters except page size should match the parameters used in the call that provided the page token.



743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. Parent can be a project, a folder, or an organization. The list is limited to the one attached to resources within the scope that a user has access to.

The allowed values are:

  • projects/{PROJECT_ID} (e.g., "projects/foo-bar")
  • projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
  • folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
  • organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456").

Returns:

  • (::String)

    Required. Parent can be a project, a folder, or an organization. The list is limited to the one attached to resources within the scope that a user has access to.

    The allowed values are:

    • projects/{PROJECT_ID} (e.g., "projects/foo-bar")
    • projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
    • folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
    • organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456")


743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signal_products_filters::Array<::Google::Cloud::DatabaseCenter::V1beta::SignalProductsFilters>

Returns Optional. Filters based on signal and product. The filter list will be ORed across pairs and ANDed within a signal and products pair.

Returns:



743
744
745
746
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 743

class QueryIssuesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end