Class: Google::Cloud::DatabaseCenter::V1beta::QueryIssuesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::QueryIssuesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
QueryIssuesResponse is the response containing a list of issues.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page. -
#resource_issues ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::DatabaseResourceIssue>
List of issues and resource details.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
773 774 775 776 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 773 class QueryIssuesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_issues ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::DatabaseResourceIssue>
Returns List of issues and resource details.
773 774 775 776 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 773 class QueryIssuesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. List of unreachable regions from where data could not be retrieved.
773 774 775 776 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 773 class QueryIssuesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |