Class: Google::Cloud::DatabaseCenter::V1beta::QueryProductsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::QueryProductsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
QueryProductsResponse represents the response containing a list of products.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token that can be sent as
page_tokento retrieve the next page. -
#products ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Product>
List of database products returned.
-
#unreachable ⇒ ::Array<::String>
Unordered list.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
70 71 72 73 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 70 class QueryProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#products ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Product>
Returns List of database products returned.
70 71 72 73 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 70 class QueryProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unordered list. List of unreachable regions from where data could not be retrieved.
70 71 72 73 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 70 class QueryProductsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |