Class: Google::Cloud::DatabaseCenter::V1beta::ResourceDetails

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

Capture the resource details for resources that are included in the delta counts.

Instance Attribute Summary collapse

Instance Attribute Details

#container::String

Returns Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.

Returns:

  • (::String)

    Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.



836
837
838
839
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836

class ResourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#full_resource_name::String

Returns Full resource name of the resource.

Returns:

  • (::String)

    Full resource name of the resource.



836
837
838
839
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836

class ResourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#location::String

Returns Location of the resource.

Returns:

  • (::String)

    Location of the resource.



836
837
838
839
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836

class ResourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product::Google::Cloud::DatabaseCenter::V1beta::Product

Returns Product type of the resource.

Returns:



836
837
838
839
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836

class ResourceDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end