Class: Google::Cloud::DatabaseCenter::V1beta::ResourceId

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/service.rb

Overview

ResourceId contains the identifier for a database resource, including the full resource name, resource type, and product.

Instance Attribute Summary collapse

Instance Attribute Details

#full_resource_name::String

Returns The full resource name of the resource.

Returns:

  • (::String)

    The full resource name of the resource.



646
647
648
649
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 646

class ResourceId
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#product::Google::Cloud::DatabaseCenter::V1beta::Product

Returns The product of the resource, including the type, engine, and version.

Returns:



646
647
648
649
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 646

class ResourceId
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_type::String

Returns The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.googleapis.com/Instance.

Returns:

  • (::String)

    The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.googleapis.com/Instance



646
647
648
649
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 646

class ResourceId
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end