Class: Google::Cloud::DatabaseCenter::V1beta::ResourceMaintenanceSchedule

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb

Overview

Maintenance window for the database resource. It specifies preferred time and day of the week and phase in some cases, when the maintenance can start.

Instance Attribute Summary collapse

Instance Attribute Details

#day::Google::Type::DayOfWeek

Returns Optional. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.

Returns:



42
43
44
45
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 42

class ResourceMaintenanceSchedule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#phase::Google::Cloud::DatabaseCenter::V1beta::Phase

Returns Optional. Phase of the maintenance window. This is to capture order of maintenance. For example, for Cloud SQL resources, this can be used to capture if the maintenance window is in Week1, Week2, Week5, etc. Non production resources are usually part of early phase. For more details, refer to Cloud SQL resources - https://cloud.google.com/sql/docs/mysql/maintenance.

Returns:



42
43
44
45
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 42

class ResourceMaintenanceSchedule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Type::TimeOfDay

Returns Optional. Preferred time to start the maintenance operation on the specified day.

Returns:



42
43
44
45
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 42

class ResourceMaintenanceSchedule
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end