Class: Google::Cloud::DatabaseCenter::V1beta::Signal

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/signals.rb

Overview

Represents a signal.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_details::Array<::Google::Cloud::DatabaseCenter::V1beta::AdditionalDetail>

Returns Additional information related to the signal. In the case of composite signals, this field encapsulates details associated with granular signals, having a signal status of "ISSUE"; signals with a status of "OK" are not included. For granular signals, it encompasses information relevant to the signal, regardless of the signal status.

Returns:

  • (::Array<::Google::Cloud::DatabaseCenter::V1beta::AdditionalDetail>)

    Additional information related to the signal. In the case of composite signals, this field encapsulates details associated with granular signals, having a signal status of "ISSUE"; signals with a status of "OK" are not included. For granular signals, it encompasses information relevant to the signal, regardless of the signal status.



440
441
442
443
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 440

class Signal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issue_create_time::Google::Protobuf::Timestamp

Returns Timestamp when the issue was created (when signal status is ISSUE).

Returns:



440
441
442
443
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 440

class Signal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issue_severity::Google::Cloud::DatabaseCenter::V1beta::IssueSeverity

Returns Severity of the issue.

Returns:



440
441
442
443
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 440

class Signal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signal_status::Google::Cloud::DatabaseCenter::V1beta::SignalStatus

Returns Status of the signal.

Returns:



440
441
442
443
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 440

class Signal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signal_type::Google::Cloud::DatabaseCenter::V1beta::SignalType

Returns Type of the signal.

Returns:



440
441
442
443
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 440

class Signal
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end