Class: Google::Cloud::DatabaseCenter::V1beta::SignalGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/signals.rb

Overview

A group of signals and their counts.

Instance Attribute Summary collapse

Instance Attribute Details

#display_name::String

Returns Title of a signal group corresponding to the request.

Returns:

  • (::String)

    Title of a signal group corresponding to the request.



86
87
88
89
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 86

class SignalGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#issue_count::Integer

Returns When applied to a DatabaseResource represents count of issues associated with the resource. A signal is an issue when its SignalStatus field is set to SIGNAL_STATUS_ISSUE.

Returns:

  • (::Integer)

    When applied to a DatabaseResource represents count of issues associated with the resource. A signal is an issue when its SignalStatus field is set to SIGNAL_STATUS_ISSUE.



86
87
88
89
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 86

class SignalGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#signals::Array<::Google::Cloud::DatabaseCenter::V1beta::Signal>

Returns List of signals present in the group and associated with the resource.

Only applies to a DatabaseResource.

Returns:



86
87
88
89
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 86

class SignalGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end