Class: Google::Cloud::DatabaseCenter::V1beta::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb

Overview

Upcoming maintenance window for the database resource.

Instance Attribute Summary collapse

Instance Attribute Details

#end_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. End time of the upcoming maintenance. This is only populated for an engine, if end time is public for the engine.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. End time of the upcoming maintenance. This is only populated for an engine, if end time is public for the engine.



75
76
77
78
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 75

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Start time of the upcoming maintenance. Start time is always populated when an upcoming maintenance is scheduled.

Returns:

  • (::Google::Protobuf::Timestamp)

    Output only. Start time of the upcoming maintenance. Start time is always populated when an upcoming maintenance is scheduled.



75
76
77
78
# File 'proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb', line 75

class UpcomingMaintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end