Class: Google::Cloud::DatabaseCenter::V1beta::AdditionalDetail
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::AdditionalDetail
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Details related to signal.
Instance Attribute Summary collapse
-
#automated_backup_policy_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::AutomatedBackupPolicyInfo
Automated backup policy information applies to signals with type SIGNAL_TYPE_NO_AUTOMATED_BACKUP_POLICY.
-
#backup_run_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo
Backup run information applies to signals with types SIGNAL_TYPE_LAST_BACKUP_FAILED and SIGNAL_TYPE_LAST_BACKUP_OLD.
-
#deletion_protection_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::DeletionProtectionInfo
Deletion protection information applies to signals with type SIGNAL_TYPE_NO_DELETION_PROTECTION.
-
#inefficient_query_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::InefficientQueryInfo
Inefficient query information applies to signals with type SIGNAL_TYPE_INEFFICIENT_QUERY.
-
#maintenance_recommendation_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MaintenanceRecommendationInfo
Maintenance recommendation information applies to signals with type SIGNAL_TYPE_RECOMMENDED_MAINTENANCE_POLICIES.
-
#outdated_minor_version_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::OutdatedMinorVersionInfo
Outdated minor version information applies to signals with type SIGNAL_TYPE_OUTDATED_MINOR_VERSION.
-
#recommendation_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::RecommendationInfo
Recommendation information applies to recommendations.
-
#resource_suspension_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::ResourceSuspensionInfo
Resource suspension information applies to signals with type SIGNAL_TYPE_RESOURCE_SUSPENDED.
-
#scc_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SCCInfo
SCC information applies to SCC signals.
-
#short_backup_retention_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::RetentionSettingsInfo
Short backup retention information applies to signals with type SIGNAL_TYPE_SHORT_BACKUP_RETENTION.
-
#signal_event_time ⇒ ::Google::Protobuf::Timestamp
Event time when signal was recorded by source service.
-
#signal_source ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SignalSource
Where the signal is coming from.
-
#signal_type ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SignalType
Type of the signal.
Instance Attribute Details
#automated_backup_policy_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::AutomatedBackupPolicyInfo
Returns Automated backup policy information applies to signals with type SIGNAL_TYPE_NO_AUTOMATED_BACKUP_POLICY.
Note: The following fields are mutually exclusive: automated_backup_policy_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#backup_run_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo
Returns Backup run information applies to signals with types SIGNAL_TYPE_LAST_BACKUP_FAILED and SIGNAL_TYPE_LAST_BACKUP_OLD.
Note: The following fields are mutually exclusive: backup_run_info, short_backup_retention_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deletion_protection_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::DeletionProtectionInfo
Returns Deletion protection information applies to signals with type SIGNAL_TYPE_NO_DELETION_PROTECTION
Note: The following fields are mutually exclusive: deletion_protection_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#inefficient_query_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::InefficientQueryInfo
Returns Inefficient query information applies to signals with type SIGNAL_TYPE_INEFFICIENT_QUERY.
Note: The following fields are mutually exclusive: inefficient_query_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#maintenance_recommendation_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::MaintenanceRecommendationInfo
Returns Maintenance recommendation information applies to signals with type SIGNAL_TYPE_RECOMMENDED_MAINTENANCE_POLICIES.
Note: The following fields are mutually exclusive: maintenance_recommendation_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#outdated_minor_version_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::OutdatedMinorVersionInfo
Returns Outdated minor version information applies to signals with type SIGNAL_TYPE_OUTDATED_MINOR_VERSION.
Note: The following fields are mutually exclusive: outdated_minor_version_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recommendation_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::RecommendationInfo
Returns Recommendation information applies to recommendations.
Note: The following fields are mutually exclusive: recommendation_info, short_backup_retention_info, backup_run_info, scc_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_suspension_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::ResourceSuspensionInfo
Returns Resource suspension information applies to signals with type SIGNAL_TYPE_RESOURCE_SUSPENDED.
Note: The following fields are mutually exclusive: resource_suspension_info, short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scc_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SCCInfo
Returns SCC information applies to SCC signals.
Note: The following fields are mutually exclusive: scc_info, short_backup_retention_info, backup_run_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#short_backup_retention_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::RetentionSettingsInfo
Returns Short backup retention information applies to signals with type SIGNAL_TYPE_SHORT_BACKUP_RETENTION.
Note: The following fields are mutually exclusive: short_backup_retention_info, backup_run_info, scc_info, recommendation_info, automated_backup_policy_info, deletion_protection_info, resource_suspension_info, inefficient_query_info, outdated_minor_version_info, maintenance_recommendation_info. If a field in that set is populated, all other fields in the set will automatically be cleared.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signal_event_time ⇒ ::Google::Protobuf::Timestamp
Returns Event time when signal was recorded by source service.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signal_source ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SignalSource
Returns Where the signal is coming from.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#signal_type ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SignalType
Returns Type of the signal.
174 175 176 177 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 174 class AdditionalDetail include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |