Class: Google::Cloud::DatabaseCenter::V1beta::Affiliation
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::Affiliation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/affiliation.rb
Overview
Affiliation information of a resource
Defined Under Namespace
Modules: ProcessType Classes: Lineage
Instance Attribute Summary collapse
-
#full_resource_name ⇒ ::String
Optional.
-
#lineages ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Affiliation::Lineage>
Optional.
-
#resource_id ⇒ ::String
Optional.
Instance Attribute Details
#full_resource_name ⇒ ::String
Returns Optional. Full resource name.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/affiliation.rb', line 37 class Affiliation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # lineage information of the affiliated resources # This captures source, target and process which created the lineage. # @!attribute [rw] source_fqn # @return [::String] # Optional. FQN of source table / column # @!attribute [rw] target_fqn # @return [::String] # Optional. FQN of target table / column # @!attribute [rw] process_fqn # @return [::String] # Optional. FQN of process which created the lineage i.e. dataplex, # datastream etc. # @!attribute [rw] process_type # @return [::Google::Cloud::DatabaseCenter::V1beta::Affiliation::ProcessType] # Optional. Type of process which created the lineage. class Lineage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of process which created the lineage. module ProcessType # Unspecified process type. PROCESS_TYPE_UNSPECIFIED = 0 # Composer process type. COMPOSER = 1 # Datastream process type. DATASTREAM = 2 # Dataflow process type. DATAFLOW = 3 # Bigquery process type. BIGQUERY = 4 # Data fusion process type. DATA_FUSION = 5 # Dataproc process type. DATAPROC = 6 end end |
#lineages ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::Affiliation::Lineage>
Returns Optional. Multiple lineages can be created from a resource. For example, a resource can be replicated to multiple target resources. In this case, there will be multiple lineages for the resource, one for each target resource.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/affiliation.rb', line 37 class Affiliation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # lineage information of the affiliated resources # This captures source, target and process which created the lineage. # @!attribute [rw] source_fqn # @return [::String] # Optional. FQN of source table / column # @!attribute [rw] target_fqn # @return [::String] # Optional. FQN of target table / column # @!attribute [rw] process_fqn # @return [::String] # Optional. FQN of process which created the lineage i.e. dataplex, # datastream etc. # @!attribute [rw] process_type # @return [::Google::Cloud::DatabaseCenter::V1beta::Affiliation::ProcessType] # Optional. Type of process which created the lineage. class Lineage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of process which created the lineage. module ProcessType # Unspecified process type. PROCESS_TYPE_UNSPECIFIED = 0 # Composer process type. COMPOSER = 1 # Datastream process type. DATASTREAM = 2 # Dataflow process type. DATAFLOW = 3 # Bigquery process type. BIGQUERY = 4 # Data fusion process type. DATA_FUSION = 5 # Dataproc process type. DATAPROC = 6 end end |
#resource_id ⇒ ::String
Returns Optional. resource id of affiliated resource.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/affiliation.rb', line 37 class Affiliation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # lineage information of the affiliated resources # This captures source, target and process which created the lineage. # @!attribute [rw] source_fqn # @return [::String] # Optional. FQN of source table / column # @!attribute [rw] target_fqn # @return [::String] # Optional. FQN of target table / column # @!attribute [rw] process_fqn # @return [::String] # Optional. FQN of process which created the lineage i.e. dataplex, # datastream etc. # @!attribute [rw] process_type # @return [::Google::Cloud::DatabaseCenter::V1beta::Affiliation::ProcessType] # Optional. Type of process which created the lineage. class Lineage include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Type of process which created the lineage. module ProcessType # Unspecified process type. PROCESS_TYPE_UNSPECIFIED = 0 # Composer process type. COMPOSER = 1 # Datastream process type. DATASTREAM = 2 # Dataflow process type. DATAFLOW = 3 # Bigquery process type. BIGQUERY = 4 # Data fusion process type. DATA_FUSION = 5 # Dataproc process type. DATAPROC = 6 end end |