Class: Google::Cloud::DatabaseCenter::V1beta::AggregateFleetRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::AggregateFleetRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
The request message to aggregate fleet which are grouped by a field.
Instance Attribute Summary collapse
-
#baseline_date ⇒ ::Google::Type::Date
Optional.
-
#filter ⇒ ::String
Optional.
-
#group_by ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#baseline_date ⇒ ::Google::Type::Date
Returns Optional. The baseline date w.r.t. which the delta counts are calculated. If not set, delta counts are not included in the response and the response indicates the current state of the fleet.
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Optional. The expression to filter resources.
Supported fields are: full_resource_name, resource_type, container,
product.type, product.engine, product.version, location,
labels, issues, fields of availability_info, data_protection_info,
'resource_name', etc.
The expression is a list of zero or more restrictions combined via logical
operators AND and OR. When AND and OR are both used in the
expression, parentheses must be appropriately used to group the
combinations.
Example: location="us-east1"
Example: container="projects/123" OR container="projects/456"
Example: (container="projects/123" OR
container="projects/456") AND location="us-east1".
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#group_by ⇒ ::String
Returns Optional. A field that statistics are grouped by. Valid values are any combination of the following:
- container
- product.type
- product.engine
- product.version
- location
- sub_resource_type
- management_type
- tag.key
- tag.value
- tag.source
- tag.inherited
- label.key
- label.value
- label.source
- has_maintenance_schedule
- has_deny_maintenance_schedules Comma separated list.
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Valid values to order by are:
- resource_groups_count
- resources_count
- and all fields supported by
group_byThe default order is ascending. Add "DESC" after the field name to indicate descending order. Add "ASC" after the field name to indicate ascending order. It supports ordering using multiple fields. For example:order_by = "resource_groups_count"sorts response in ascending orderorder_by = "resource_groups_count DESC"sorts response in descending orderorder_by = "product.type, product.version DESC, location"orders by type in ascending order, version in descending order and location in ascending order.
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. If unspecified, at most 50 items will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous AggregateFleet call.
Provide this to retrieve the subsequent page.
All other parameters should match the parameters in the call that provided
the page token except for page_size which can be different.
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent can be a project, a folder, or an organization. The search
is limited to the resources within the scope.
The allowed values are:
- projects/{PROJECT_ID} (e.g., "projects/foo-bar")
- projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
- folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
- organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456").
532 533 534 535 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 532 class AggregateFleetRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |