Class: Google::Cloud::DatabaseCenter::V1beta::AggregateQueryStatsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::AggregateQueryStatsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
AggregateQueryStatsRequest represents the input to the AggregateQueryStats method.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. The expression to filter resources.
Supported fields are: full_resource_name, resource_type, container,
product.type, product.engine, product.version, location,
labels, issues, fields of availability_info,
data_protection_info,'resource_name', etc.
The expression is a list of zero or more restrictions combined via logical
operators AND and OR. When AND and OR are both used in the
expression, parentheses must be appropriately used to group the
combinations.
Example: location="us-east1"
Example: container="projects/123" OR container="projects/456"
Example: (container="projects/123" OR
container="projects/456") AND location="us-east1"
Additional specific fields for query stats are: metric_window,
query_hash, normalized_query.
Example: metric_window="LAST_ONE_DAY"
(Possible values for metric_window are: LAST_ONE_DAY,
LAST_ONE_WEEK, LAST_TWO_WEEKS)
Example: query_hash="12345678"
Example: normalized_query="SELECT * FROM table".
415 416 417 418 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 415 class AggregateQueryStatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. The expression to order the results by.
Example: order_by="execution_count"
Example: order_by="execution_count desc"
Supported order by fields are execution_count, rows_processed,
total_cpu_time, avg_cpu_time.
415 416 417 418 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 415 class AggregateQueryStatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. If unspecified, at most 100 query stats will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
415 416 417 418 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 415 class AggregateQueryStatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous
AggregateQueryStatsRequest call. Provide this to retrieve the subsequent
page. All parameters except page_token should match the parameters in the
call that provided the page token.
415 416 417 418 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 415 class AggregateQueryStatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent can be a project, a folder, or an organization. The search
is limited to the resources within the parent.
The allowed values are:
- projects/{PROJECT_ID} (e.g., "projects/foo-bar")
- projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
- folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
- organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456").
415 416 417 418 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 415 class AggregateQueryStatsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |