Class: Google::Cloud::DatabaseCenter::V1beta::BackupDRConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::BackupDRConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
BackupDRConfig to capture the backup and disaster recovery details of database resource.
Instance Attribute Summary collapse
-
#backupdr_managed ⇒ ::Boolean
Indicates if the resource is managed by BackupDR.
Instance Attribute Details
#backupdr_managed ⇒ ::Boolean
Returns Indicates if the resource is managed by BackupDR.
694 695 696 697 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 694 class BackupDRConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |