Class: Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Metadata about latest backup run state for a database resource.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
The time the backup operation completed.
-
#error_message ⇒ ::String
Additional information about the error encountered.
-
#operation_error_type ⇒ ::Google::Cloud::DatabaseCenter::V1beta::OperationErrorType
Optional.
-
#start_time ⇒ ::Google::Protobuf::Timestamp
The time the backup operation started.
-
#state ⇒ ::Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo::State
readonly
Output only.
-
#sub_resource ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SubResource
Optional.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the backup operation completed.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |
#error_message ⇒ ::String
Returns Additional information about the error encountered.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |
#operation_error_type ⇒ ::Google::Cloud::DatabaseCenter::V1beta::OperationErrorType
Returns Optional. OperationErrorType to expose specific error when backup operation of database resource failed, that is state is FAILED.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp
Returns The time the backup operation started.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |
#state ⇒ ::Google::Cloud::DatabaseCenter::V1beta::BackupRunInfo::State (readonly)
Returns Output only. The state of this run.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |
#sub_resource ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SubResource
Returns Optional. Sub resource details associated with the backup run.
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 300 class BackupRunInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The status of a backup run. module State # Unspecified. STATE_UNSPECIFIED = 0 # The backup succeeded. SUCCEEDED = 1 # The backup was unsuccessful. FAILED = 2 end end |