Class: Google::Cloud::DatabaseCenter::V1beta::Label
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::Label
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
Label is a key value pair applied to a resource.
Instance Attribute Summary collapse
-
#key ⇒ ::String
The key part of the label.
-
#source ⇒ ::String
The source of the Label.
-
#value ⇒ ::String
The value part of the label.
Instance Attribute Details
#key ⇒ ::String
Returns The key part of the label.
444 445 446 447 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 444 class Label include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source ⇒ ::String
Returns The source of the Label. Source is empty if the label is directly attached to the resource and not inherited.
444 445 446 447 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 444 class Label include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |