Module: Google::Cloud::DatabaseCenter::V1beta::PossibleFailureReason
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/maintenance.rb
Overview
Possible reasons why the maintenance is not completed. STATE_FAILED maintenance state may not always have a failure reason.
Constant Summary collapse
- POSSIBLE_FAILURE_REASON_UNSPECIFIED =
Failure reason is unspecified.
0- POSSIBLE_FAILURE_REASON_DENY_POLICY_CONFLICT =
Maintenance may not be completed because there is a deny policy overlapping with upcoming maintenance schedule.
1- POSSIBLE_FAILURE_REASON_INSTANCE_IN_STOPPED_STATE =
Maintenance may not be completed because the instance is stopped.
2