Class: Google::Cloud::DatabaseCenter::V1beta::QueryMetrics
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::QueryMetrics
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
QueryMetrics contains the metrics related to the query execution.
Defined Under Namespace
Modules: MetricsWindow
Instance Attribute Summary collapse
-
#avg_cpu_time ⇒ ::Google::Protobuf::Duration
The average execution period of the query across all runs.
-
#execution_count ⇒ ::Integer
The number of times the query was executed.
-
#metrics_window ⇒ ::Google::Cloud::DatabaseCenter::V1beta::QueryMetrics::MetricsWindow
The window over which the metrics are aggregated.
-
#rows_processed ⇒ ::Integer
The average number of rows processed by the query across all runs.
-
#total_cpu_time ⇒ ::Google::Protobuf::Duration
The total CPU time consumed by the query across all runs.
Instance Attribute Details
#avg_cpu_time ⇒ ::Google::Protobuf::Duration
Returns The average execution period of the query across all runs.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 695 class QueryMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum to represent the window over which the metrics are aggregated. module MetricsWindow # Unspecified. Default value. METRICS_WINDOW_UNSPECIFIED = 0 # Metrics are aggregated over the last 1 day. LAST_ONE_DAY = 1 # Metrics are aggregated over the last 7 days. LAST_ONE_WEEK = 2 # Metrics are aggregated over the last 14 days. LAST_TWO_WEEKS = 3 end end |
#execution_count ⇒ ::Integer
Returns The number of times the query was executed.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 695 class QueryMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum to represent the window over which the metrics are aggregated. module MetricsWindow # Unspecified. Default value. METRICS_WINDOW_UNSPECIFIED = 0 # Metrics are aggregated over the last 1 day. LAST_ONE_DAY = 1 # Metrics are aggregated over the last 7 days. LAST_ONE_WEEK = 2 # Metrics are aggregated over the last 14 days. LAST_TWO_WEEKS = 3 end end |
#metrics_window ⇒ ::Google::Cloud::DatabaseCenter::V1beta::QueryMetrics::MetricsWindow
Returns The window over which the metrics are aggregated.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 695 class QueryMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum to represent the window over which the metrics are aggregated. module MetricsWindow # Unspecified. Default value. METRICS_WINDOW_UNSPECIFIED = 0 # Metrics are aggregated over the last 1 day. LAST_ONE_DAY = 1 # Metrics are aggregated over the last 7 days. LAST_ONE_WEEK = 2 # Metrics are aggregated over the last 14 days. LAST_TWO_WEEKS = 3 end end |
#rows_processed ⇒ ::Integer
Returns The average number of rows processed by the query across all runs.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 695 class QueryMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum to represent the window over which the metrics are aggregated. module MetricsWindow # Unspecified. Default value. METRICS_WINDOW_UNSPECIFIED = 0 # Metrics are aggregated over the last 1 day. LAST_ONE_DAY = 1 # Metrics are aggregated over the last 7 days. LAST_ONE_WEEK = 2 # Metrics are aggregated over the last 14 days. LAST_TWO_WEEKS = 3 end end |
#total_cpu_time ⇒ ::Google::Protobuf::Duration
Returns The total CPU time consumed by the query across all runs.
695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 695 class QueryMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum to represent the window over which the metrics are aggregated. module MetricsWindow # Unspecified. Default value. METRICS_WINDOW_UNSPECIFIED = 0 # Metrics are aggregated over the last 1 day. LAST_ONE_DAY = 1 # Metrics are aggregated over the last 7 days. LAST_ONE_WEEK = 2 # Metrics are aggregated over the last 14 days. LAST_TWO_WEEKS = 3 end end |