Class: Google::Cloud::DatabaseCenter::V1beta::QueryProductsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::QueryProductsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
QueryProductsRequest is the request to get a list of products.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. If unspecified, at most 50 products will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.
53 54 55 56 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 53 class QueryProductsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListLocations call.
Provide this to retrieve the subsequent page.
All other parameters except page size should match the call that provided
the page page token.
53 54 55 56 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 53 class QueryProductsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. Parent can be a project, a folder, or an organization.
The allowed values are:
- projects/{PROJECT_ID}/locations/{LOCATION} (e.g.,"projects/foo-bar/locations/us-central1")
- projects/{PROJECT_NUMBER}/locations/{LOCATION} (e.g.,"projects/12345678/locations/us-central1")
- folders/{FOLDER_NUMBER}/locations/{LOCATION} (e.g.,"folders/1234567/locations/us-central1")
- organizations/{ORGANIZATION_NUMBER}/locations/{LOCATION} (e.g.,"organizations/123456/locations/us-central1")
- projects/{PROJECT_ID} (e.g., "projects/foo-bar")
- projects/{PROJECT_NUMBER} (e.g., "projects/12345678")
- folders/{FOLDER_NUMBER} (e.g., "folders/1234567")
- organizations/{ORGANIZATION_NUMBER} (e.g., "organizations/123456").
53 54 55 56 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 53 class QueryProductsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |