Class: Google::Cloud::DatabaseCenter::V1beta::QueryStats
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::QueryStats
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
QueryStats contains the stats for a particular combination of query_hash, query_string and resource_type.
Instance Attribute Summary collapse
-
#inefficient_query_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::InefficientQueryInfo
Information about inefficient query.
-
#normalized_query ⇒ ::String
The query string is normalized query without any PII data.
-
#query_hash ⇒ ::String
The query hash of the query.
-
#query_metrics ⇒ ::Google::Cloud::DatabaseCenter::V1beta::QueryMetrics
Metrics related to the query performance.
-
#resource_ids ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::ResourceId>
The resource ids for which the query stats are collected.
-
#resource_type ⇒ ::String
The type of the resource.
Instance Attribute Details
#inefficient_query_info ⇒ ::Google::Cloud::DatabaseCenter::V1beta::InefficientQueryInfo
Returns Information about inefficient query.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#normalized_query ⇒ ::String
Returns The query string is normalized query without any PII data.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_hash ⇒ ::String
Returns The query hash of the query.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query_metrics ⇒ ::Google::Cloud::DatabaseCenter::V1beta::QueryMetrics
Returns Metrics related to the query performance.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_ids ⇒ ::Array<::Google::Cloud::DatabaseCenter::V1beta::ResourceId>
Returns The resource ids for which the query stats are collected.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String
Returns The type of the resource. sqladmin.googleapis.com/Instance alloydb.googleapis.com/Cluster alloydb.googleapis.com/Instance.
674 675 676 677 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 674 class QueryStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |