Class: Google::Cloud::DatabaseCenter::V1beta::RecommendationInfo
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::RecommendationInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Info associated with recommendation.
Instance Attribute Summary collapse
-
#recommender ⇒ ::String
Name of recommendation.
-
#recommender_id ⇒ ::String
ID of recommender.
-
#recommender_subtype ⇒ ::String
Contains an identifier for a subtype of recommendations produced for the same recommender.
Instance Attribute Details
#recommender ⇒ ::String
Returns Name of recommendation. Examples: organizations/1234/locations/us-central1/recommenders/google.cloudsql.instance.PerformanceRecommender/recommendations/9876.
380 381 382 383 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 380 class RecommendationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recommender_id ⇒ ::String
Returns ID of recommender. Examples: "google.cloudsql.instance.PerformanceRecommender".
380 381 382 383 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 380 class RecommendationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recommender_subtype ⇒ ::String
Returns Contains an identifier for a subtype of recommendations produced for the
same recommender. Subtype is a function of content and impact, meaning a
new subtype might be added when significant changes to content or
primary_impact.category are introduced. See the Recommenders section
to see a list of subtypes for a given Recommender.
Examples: For recommender = "google.cloudsql.instance.PerformanceRecommender", recommender_subtype can be "MYSQL_HIGH_NUMBER_OF_OPEN_TABLES_BEST_PRACTICE"/"POSTGRES_HIGH_TRANSACTION_ID_UTILIZATION_BEST_PRACTICE".
380 381 382 383 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 380 class RecommendationInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |