Class: Google::Cloud::DatabaseCenter::V1beta::RegulatoryStandard
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::RegulatoryStandard
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Compliances associated with signals.
Instance Attribute Summary collapse
-
#standard ⇒ ::String
Name of industry compliance standards, such as such as CIS, PCI, and OWASP.
-
#version ⇒ ::String
Version of the standard or benchmark, for example, 1.1.
Instance Attribute Details
#standard ⇒ ::String
Returns Name of industry compliance standards, such as such as CIS, PCI, and OWASP.
393 394 395 396 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 393 class RegulatoryStandard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#version ⇒ ::String
Returns Version of the standard or benchmark, for example, 1.1.
393 394 395 396 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 393 class RegulatoryStandard include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |