Class: Google::Cloud::DatabaseCenter::V1beta::ResourceDetails
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::ResourceDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/service.rb
Overview
Capture the resource details for resources that are included in the delta counts.
Instance Attribute Summary collapse
-
#container ⇒ ::String
Specifies where the resource is created.
-
#full_resource_name ⇒ ::String
Full resource name of the resource.
-
#location ⇒ ::String
Location of the resource.
-
#product ⇒ ::Google::Cloud::DatabaseCenter::V1beta::Product
Product type of the resource.
Instance Attribute Details
#container ⇒ ::String
Returns Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.
836 837 838 839 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836 class ResourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#full_resource_name ⇒ ::String
Returns Full resource name of the resource.
836 837 838 839 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836 class ResourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#location ⇒ ::String
Returns Location of the resource.
836 837 838 839 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836 class ResourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product ⇒ ::Google::Cloud::DatabaseCenter::V1beta::Product
Returns Product type of the resource.
836 837 838 839 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/service.rb', line 836 class ResourceDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |