Class: Google::Cloud::DatabaseCenter::V1beta::RetentionSettingsInfo
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::RetentionSettingsInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Metadata about backup retention settings for a database resource.
Instance Attribute Summary collapse
-
#duration_based_retention ⇒ ::Google::Protobuf::Duration
Duration based retention period i.e.
-
#quantity_based_retention ⇒ ::Google::Protobuf::Int32Value
Number of backups that will be retained.
-
#sub_resource ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SubResource
Optional.
-
#timestamp_based_retention_time ⇒ ::Google::Protobuf::Timestamp
Timestamp based retention period i.e.
Instance Attribute Details
#duration_based_retention ⇒ ::Google::Protobuf::Duration
Returns Duration based retention period i.e. 172800 seconds (2 days)
Note: The following fields are mutually exclusive: duration_based_retention, quantity_based_retention, timestamp_based_retention_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
239 240 241 242 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 239 class RetentionSettingsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#quantity_based_retention ⇒ ::Google::Protobuf::Int32Value
Returns Number of backups that will be retained.
Note: The following fields are mutually exclusive: quantity_based_retention, duration_based_retention, timestamp_based_retention_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
239 240 241 242 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 239 class RetentionSettingsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#sub_resource ⇒ ::Google::Cloud::DatabaseCenter::V1beta::SubResource
Returns Optional. Sub resource details associated with the backup configuration.
239 240 241 242 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 239 class RetentionSettingsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#timestamp_based_retention_time ⇒ ::Google::Protobuf::Timestamp
Returns Timestamp based retention period i.e. till 2024-05-01T00:00:00Z
Note: The following fields are mutually exclusive: timestamp_based_retention_time, quantity_based_retention, duration_based_retention. If a field in that set is populated, all other fields in the set will automatically be cleared.
239 240 241 242 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 239 class RetentionSettingsInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |