Class: Google::Cloud::DatabaseCenter::V1beta::SubResource
- Inherits:
-
Object
- Object
- Google::Cloud::DatabaseCenter::V1beta::SubResource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/databasecenter/v1beta/signals.rb
Overview
Sub resource details For Spanner/Bigtable instance certain data protection settings are at sub resource level like database/table. This message is used to capture such sub resource details.
Instance Attribute Summary collapse
-
#container ⇒ ::String
Specifies where the resource is created.
-
#full_resource_name ⇒ ::String
Optional.
-
#product ⇒ ::Google::Cloud::DatabaseCenter::V1beta::Product
Optional.
-
#resource_type ⇒ ::String
Optional.
Instance Attribute Details
#container ⇒ ::String
Returns Specifies where the resource is created. For Google Cloud resources, it is the full name of the project.
215 216 217 218 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 215 class SubResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#full_resource_name ⇒ ::String
Returns Optional. Resource name associated with the sub resource where backup settings are configured. E.g."//spanner.googleapis.com/projects/project1/instances/inst1/databases/db1" for Spanner where backup retention is configured on database within an instance OPTIONAL.
215 216 217 218 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 215 class SubResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#product ⇒ ::Google::Cloud::DatabaseCenter::V1beta::Product
Returns Optional. Product information associated with the sub resource where backup retention settings are configured. e.g.
product: {
type : PRODUCT_TYPE_SPANNER
engine : ENGINE_CLOUD_SPANNER_WITH_POSTGRES_DIALECT
}
for Spanner where backup is configured on database within an instance OPTIONAL.
215 216 217 218 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 215 class SubResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_type ⇒ ::String
Returns Optional. Resource type associated with the sub resource where backup settings are configured. E.g. "spanner.googleapis.com/Database" for Spanner where backup retention is configured on database within an instance OPTIONAL.
215 216 217 218 |
# File 'proto_docs/google/cloud/databasecenter/v1beta/signals.rb', line 215 class SubResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |